# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-04 09:13
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Consumer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=128, unique=True, verbose_name='Key')),
                ('secret', models.CharField(max_length=128, unique=True, verbose_name='Secret')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Consumer',
                'verbose_name_plural': 'Consumers',
            },
        ),
        migrations.CreateModel(
            name='TimestampAndNonce',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.IntegerField(verbose_name='Timestamp')),
                ('nonce', models.CharField(max_length=128, verbose_name='Nonce')),
                ('consumer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='lti_provider.Consumer', verbose_name='Consumer')),
            ],
            options={
                'verbose_name': 'Timestamp and Nonce',
                'verbose_name_plural': 'Timestamps and Nonces',
            },
        ),
        migrations.AlterUniqueTogether(
            name='timestampandnonce',
            unique_together=set([('timestamp', 'nonce')]),
        ),
    ]
